@@ -22,6 +22,15 @@
 
 #include <config.h>
 
+/**
+ * SECTION:glade-project
+ * @Short_Description: The Glade document hub and Load/Save interface.
+ *
+ * This object owns all project objects and is responsable for loading and
+ * saving the glade document, you can monitor the project state via this
+ * object and its signals.
+ */
+
 #include <string.h>
 #include <stdlib.h>
 #include <glib.h>
@@ -97,7 +106,6 @@ struct _GladeProjectPrivate
 	GList       *prev_redo_item;          /* Points to the item previous to the redo items */
 	GHashTable  *widget_names_allocator;  /* hash table with the used widget names */
 	GHashTable  *widget_old_names;        /* widget -> old name of the widget */
-	GtkTooltips *tooltips;
 	
 	GladeCommand *first_modification; /* we record the first modification, so that we
 	                                   * can set "modification" to FALSE when we
@@ -193,9 +201,6 @@ glade_project_dispose (GObject *object)
 	}
 	project->priv->objects = NULL;
 
-	gtk_object_destroy (GTK_OBJECT (project->priv->tooltips));
-	project->priv->tooltips = NULL;
-
 	G_OBJECT_CLASS (glade_project_parent_class)->dispose (object);
 }
 
@@ -480,7 +485,6 @@ glade_project_init (GladeProject *project)
 				       
 	priv->widget_old_names = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify) g_free);
 
-	priv->tooltips = gtk_tooltips_new ();
 	priv->accel_group = NULL;
 
 	priv->resources = g_hash_table_new_full (g_direct_hash, 
@@ -683,8 +687,8 @@ glade_project_class_init (GladeProjectClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_MODIFIED,
 					 g_param_spec_boolean ("modified",
-							       _(""),
-							       _("Whether project has beem modified since it was last saved"),
+							       "Modified",
+							       _("Whether project has been modified since it was last saved"),
 							       FALSE,
 							       G_PARAM_READABLE));
 
@@ -1962,6 +1966,8 @@ glade_project_undo_items (GladeProject *project)
 	GladeCommand *cmd;
 	GList   *l;
 
+	g_return_val_if_fail (project != NULL, NULL);
+
 	for (l = project->priv->prev_redo_item; l; l = walk_command (l, FALSE))
 	{
 		cmd = l->data;
@@ -1997,6 +2003,8 @@ glade_project_redo_items (GladeProject *project)
 	GladeCommand *cmd;
 	GList   *l;
 
+	g_return_val_if_fail (project != NULL, NULL);
+
 	for (l = project->priv->prev_redo_item ?
 		     project->priv->prev_redo_item->next :
 		     project->priv->undo_stack;
@@ -2027,19 +2035,6 @@ glade_project_reset_path (GladeProject *project)
 	project->priv->path = (g_free (project->priv->path), NULL);
 }
 
-/**
- * glade_project_get_tooltips:
- * @project: a #GladeProject
- *
- * Returns: a #GtkTooltips object containing all tooltips for @project
- */
-GtkTooltips *
-glade_project_get_tooltips (GladeProject *project)
-{
-	g_return_val_if_fail (GLADE_IS_PROJECT (project), NULL);
-	return project->priv->tooltips;
-}
-
 /**
  * glade_project_set_accel_group:
  * @project: A #GladeProject
